package com.nisum.service;

import com.nisum.dao.Dao;
import com.nisum.dao.impl.EmployeeDao;
import com.nisum.dto.EmployeeDto;
import com.nisum.helper.EmployeeHelper;
import com.nisum.model.Employee;
import com.nisum.model.impl.EmployeeImp;
import com.nisum.model.impl.JobRoleImp;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import java.util.Collection;
import java.util.Optional;

@Service
public class EmployeeService {

  @Autowired
  @Qualifier(value = "EmployeeDao")
  private Dao<EmployeeImp> employeeDao;

  @Autowired
  EmployeeHelper employeeHelper;

  public Collection<EmployeeImp> getAllEmployees() {
    return employeeDao.getAll();
  }

  public Optional<EmployeeImp> get(int employeeId) {
    return employeeDao.getById(employeeId);
  }

  public void createEmployee(EmployeeDto employeeDto) {
    EmployeeImp employeeImp = new EmployeeImp();
    JobRoleImp jobRoleImp = new JobRoleImp(employeeDto.getJobTitle());
    employeeImp.setFirstName(employeeDto.getFirstName());
    employeeImp.setLastName(employeeDto.getLastName());
    employeeImp.setJobRole(jobRoleImp);
    employeeDao.save(employeeImp);
  }

  public void delete(int employeeId) {
    Optional<EmployeeImp> employeeImp = employeeDao.getById(employeeId);
    employeeImp.ifPresent(imp -> employeeDao.delete(imp));
  }

  public void update(EmployeeDto employeeDto) {
    EmployeeImp employeeImp = new EmployeeImp();
    JobRoleImp jobRoleImp = new JobRoleImp(employeeDto.getJobTitle());
    employeeImp.setFirstName(employeeDto.getFirstName());
    employeeImp.setLastName(employeeDto.getLastName());
    employeeImp.setJobRole(jobRoleImp);
    employeeDao.update(employeeImp);
  }
}
